// 定义运行状态字典
const runStatDict = {
    0: {
        label: '离线',
        color: 'lightgray'
    },
    1: {
        label: '在线',
        color: 'yellowgreen'
    },
    2: {
        label: '未关联',
        color: 'lightgray'
    }
}

// 定义运行模式字典
const runModeDict = {
    0: {
        label: '无',
        color: 'lightgray'
    },
    1: {
        label: '制冷',
        color: 'darkgreen'
    },
    2: {
        label: '采暖',
        color: 'orange'
    },
    3: {
        label: '除湿',
        color: 'rgb(182, 172, 195)'
    },
    4: {
        label: '预热',
        color: 'yellow'
    },
    5: {
        label: '通风',
        color: 'rgb(182, 174, 227)'
    }
}

// 定义连接状态字典
const connectStatDict = {
    0: {
        label: '正常',
        color: 'yellowgreen'
    }
}

// 定义故障字典
const faultDict = {
    0: {
        label: '无',
        color: 'yellowgreen'
    },
    1: {
        label: '有',
        color: 'yellow'
    }
}

// 定义换热站水泵状态字典
const hexPumpStatDict = {
    0: {
        label: '停止',
        color: 'yellow'
    },
    1: {
        label: '运行',
        color: 'yellowgreen'
    }
}

// 运行状态选项定义
const runStatOpts = [{
    label: '在线',
    value: '1'
},
    {
        label: '离线',
        value: '0'
    }
]

// 运行模式选项定义
const runModeOpts = [{
    label: '制冷',
    value: '1'
},
    {
        label: '采暖',
        value: '2'
    },
    {
        label: '除湿',
        value: '3'
    },
    {
        label: '预热',
        value: '4'
    },
    {
        label: '通风',
        value: '5'
    },
	{
		label: '无',
		value: '0'
	}
]

// 定义弹窗的主机列
const hostCols = [{
    prop: 'host_order',
    label: '编号',
    width: 60
},
    {
        prop: 'host_connect_status',
        label: '通讯状态'
    },
    {
        prop: 'host_fault',
        label: '故障'
    },
    {
        prop: 'host_su_temp',
        label: '供水水温（℃）'
    },
    {
        prop: 'host_re_temp',
        label: '回水水温（℃）'
    },
    {
        prop: 'host_temp_diff',
        label: '温差（℃）'
    }
]

// 新风机列
const newTrendCols = [{
    prop: 'nt_order',
    label: '编号',
    width: 60
},
    {
        prop: 'nt_connect_status',
        label: '通讯状态'
    },
    {
        prop: 'nt_fault',
        label: '故障'
    },
    {
        prop: 'nt_in_temp',
        label: '送风温度（℃）'
    },
    {
        prop: 'nt_in_humidity',
        label: '送风湿度（℃）'
    },
    {
        prop: 'nt_dew_point',
        label: '露点（℃）'
    }
]

// 换热站列
const heatExchangeCols = [{
    prop: 'hex_order',
    label: '编号',
    width: 60
},
    {
        prop: 'hex_connect_status',
        label: '通讯状态'
    },
    {
        prop: 'hex_fault',
        label: '故障'
    },
    {
        prop: 'hex_su_temp',
        label: '供水水温（℃）'
    },
    {
        prop: 'hex_re_temp',
        label: '回水水温（℃）'
    },
    {
        prop: 'hex_temp_diff',
        label: '温差（℃）'
    },
    {
        prop: 'hex_pump_status',
        label: '水泵状态'
    }
]

// 末端列
const endCols = [{
    prop: 'end_order',
    label: '编号',
    width: 60
},
    {
        prop: 'end_min_temp',
        label: '室内温度（℃）'
    },
    {
        prop: 'end_min_humidity',
        label: '室内湿度（%）'
    },
    {
        prop: 'end_min_dew_point',
        label: '室内露点（℃）'
    }
    // {
    // 	prop: 'end_min_temp',
    // 	label: '最低室内温度（℃）'
    // },
    // {
    // 	prop: 'end_min_humidity',
    // 	label: '最低室内湿度（%）'
    // },
    // {
    // 	prop: 'end_min_dew_point',
    // 	label: '最低室内露点（℃）'
    // },
    // {
    // 	prop: 'end_max_temp',
    // 	label: '最高室内温度（℃）'
    // },
    // {
    // 	prop: 'end_max_humidity',
    // 	label: '最高室内湿度（%）'
    // },
    // {
    // 	prop: 'end_max_dew_point',
    // 	label: '最高室内露点（℃）'
    // }
]

/**
 * 取最大单机数
 */
function calcMaxStandaloneCnt(box) {
    let hpStandaloneCnt = box.hostCtrl ? box.hostCtrl.length : 0
    let dhStandaloneCnt = box.newTrendCtrl ? box.newTrendCtrl.length : 0
    let hexStandaloneCnt = box.hex ? box.hex.length : 0
    // 需求：末端最多显示一行，其他类型设备最多两行。如果其他类型设备超过一行，末端需要合并
    // 如果主机新风机换热站的单机数都是0，还需取一下末端的数量(最大为1)
    let max = Math.max(hpStandaloneCnt, dhStandaloneCnt, hexStandaloneCnt)
    max = Math.min(2, max)
    if (max <= 0) {
        let cbStandaloneCnt = box.end ? box.end.length : 0
        max = Math.min(cbStandaloneCnt, 1)
    }
    return max
}

/**
 * 计算每个盒子下末端的最大值与最小值
 */
export function calcEndMinAndMaxValue(standalone) {
    let tmp = {
        end_exception_num: 0,
        end_min_temp: 10000,
        end_min_humidity: 10000,
        end_min_dew_point: 10000,
        end_max_temp: 0,
        end_max_humidity: 0,
        end_max_dew_point: 0
    }
    standalone.forEach(s => {
        tmp.end_exception_num += s.end_exception_num
        if (s.end_min_temp != 0) {
            tmp.end_min_temp = Math.min(tmp.end_min_temp, s.end_min_temp)
        }
        if (s.end_min_humidity != 0) {
            tmp.end_min_humidity = Math.min(tmp.end_min_humidity, s.end_min_humidity)
        }
        if (s.end_min_dew_point != 0) {
            tmp.end_min_dew_point = Math.min(tmp.end_min_dew_point, s.end_min_dew_point)
        }
        if (s.end_max_temp != 0) {
            tmp.end_max_temp = Math.max(tmp.end_max_temp, s.end_max_temp)
        }
        if (s.end_max_humidity != 0) {
            tmp.end_max_humidity = Math.max(tmp.end_max_humidity, s.end_max_humidity)
        }
        if (s.end_max_dew_point != 0) {
            tmp.end_max_dew_point = Math.max(tmp.end_max_dew_point, s.end_max_dew_point)
        }
    })
    if (tmp.end_min_temp == 10000) {
        tmp.end_min_temp = 0
    }
    if (tmp.end_min_humidity == 10000) {
        tmp.end_min_humidity = 0
    }
    if (tmp.end_min_dew_point == 10000) {
        tmp.end_min_dew_point = 0
    }
    return tmp
}

/**
 * 函数：通过数组描述执行表达式，得到变量对应的颜色
 */
function getArgsColor(argsList, runMode, val) {
    let evalString = ""
    if (argsList.length <= 0) {
        return evalString
    }

    var color = ''
    // 先找出条件中有模式的数组跟无模式的数组
    // 先拼接带有模式的数组, 再组合一下无模式的数组
    let runModeArgs = argsList.filter(args => args.RunMode > 0)
    let noneRunModeArgs = argsList.filter(args => args.RunMode <= 0)
    runModeArgs.forEach(args => {
        evalString += `if (runMode==${args.RunMode}) {color=val${args.Action}${args.Threshold}?'yellow':''} else `
    })
    if (noneRunModeArgs.length > 0) {
        let tmp = 'if (';
        noneRunModeArgs.forEach(args => {
            tmp += `val${args.Action}${args.Threshold}`
            tmp += '||'
        })
        tmp = tmp.substring(0, tmp.length - 2)
        tmp += `) {color='yellow'} else {color=''}`
        evalString += tmp
    } else {
        evalString = evalString.substring(0, evalString.length - 5)
    }

    // if (argsList[0].En === 'nt_dew_point') {
    // 	console.log(">>> argsList: ", argsList, runMode, val)
    // 	console.log(">>> evalString: ", evalString)
    // }

    // 执行命令
    eval(evalString)
    return color
}

/**
 * 数据回显设置
 */
function formatData(data, prop) {
    let val = data[prop];
    // 如果为通讯状态（即后缀为：_connect_status），需要转成对应的描述
    if (prop.indexOf("_connect_status") >= 0) {
        return connectStatDict[val] ? connectStatDict[val].label : "异常";
    }
    // 如果为故障标识（即后缀为：_fault），需要转成对应的描述
    else if (prop.indexOf("_fault") >= 0) {
        return faultDict[val] ? faultDict[val].label : "/";
    }
    // 如果为水泵状态（即后缀为：_pump_status），需要转成对应的描述
    else if (prop.indexOf("_pump_status") >= 0) {
        return hexPumpStatDict[val] ? hexPumpStatDict[val].label : "/";
    }
    // 如果为编号或异常数（即后缀为：_order/_exception_num），直接显示
    else if (prop.indexOf("_order") >= 0 || prop.indexOf("_exception_num") >= 0) {
        return val;
    }
    // 否则全都格式化(值为0显示为/，不为0保留1位小数)
    else if (val != 0) {
        return parseFloat(val).toFixed(1);
    } else {
        if (prop == "host_temp_diff") {
            if (data.host_su_temp && data.host_su_temp) {
                let host_su_temp = parseFloat(data.host_su_temp).toFixed(1);
                let host_re_temp = parseFloat(data.host_re_temp).toFixed(1);
                return host_su_temp == host_re_temp ? 0 : val;
            } else {
                return data[prop] || "/";
            }
        } else {
            return val || "/";
        }
    }
}

export default {
    runStatDict,
    runModeDict,
    connectStatDict,
    faultDict,
    hexPumpStatDict,
    runStatOpts,
    runModeOpts,
    hostCols,
    newTrendCols,
    heatExchangeCols,
    endCols,
    calcMaxStandaloneCnt,
    calcEndMinAndMaxValue,
    getArgsColor,
    formatData
}
