import define from './common.js'

// 展开所有数据
export function expandAllNodes(projects) {
	let tableData = []
	projects.forEach((p, index) => {
		if (Array.isArray(p.boxList)) {
			p.boxList.forEach(b => {
				// 继续判断有多少单机，主机、新风机、换热站、末端单机数量取最大值
				let maxCnt = define.calcMaxStandaloneCnt(b)
				for (let i = 0; i < maxCnt; i++) {
					let hpStandalone = b.hostCtrl && i < b.hostCtrl.length ? b.hostCtrl[i] : {}
					let dhStandalone = b.newTrendCtrl && i < b.newTrendCtrl.length ? b.newTrendCtrl[i] : {}
					let hexStandalone = b.hex && i < b.hex.length ? b.hex[i] : {}
					let cbStandalone = define.calcEndMinAndMaxValue(b.end || [])
					tableData.push({
            // projectId: p.project_auto_id,
            projectId: index + 1,
            projectName: p.projectName,
            boxId: b.box_id,
            boxName: b.boxName,
            runStatus: b.runStatus,
            runMode: b.runMode,
            hpCnt: b.hostCtrl && b.hostCtrl.length,
            dhCnt: b.newTrendCtrl && b.newTrendCtrl.length,
            hexCnt: b.hex && b.hex.length,
            cbCnt: b.end && b.end.length,
            maxCnt,
            standaloneIndex: i,
            ...hpStandalone,
            ...dhStandalone,
            ...hexStandalone,
            ...cbStandalone,
          });
				}
			})
		}
	})
	// 合并单机
	return _getStandaloneSpanRows(tableData)
}

// 合并行数据
export function mergeTableRows(data, merge) {
	if (!merge || merge.length === 0) {
		return data
	}
	merge.forEach(m => {
		const mList = {}
		let spliceLocation = merge.indexOf(m)
		data = data.map((v, index) => {
			const rowVal = v[m]
			if (mList[rowVal] && mList[rowVal].newIndex === index) {
				let flag = false
				let mergeSolve = merge.slice(0, spliceLocation)
				mergeSolve.slice(0, spliceLocation).forEach(mergeItem => {
					// 需要以盒子名称的维度来合并
					if (data[index][mergeItem] == data[index - 1][mergeItem] && 
						data[index]["boxName"] == data[index - 1]["boxName"]) {
						flag = true
					}
				})
				if (m == merge[0]) {
					flag = true
				}
				if (flag) {
					mList[rowVal]["num"]++
					mList[rowVal]["newIndex"]++
					data[mList[rowVal]["index"]][m + "-span"].rowspan++
					v[m + "-span"] = {
						rowspan: 0,
						colspan: 0,
					}
				} else {
					mList[rowVal] = {
						num: 1,
						index: index,
						newIndex: index + 1,
					}
					v[m + "-span"] = {
						rowspan: 1,
						colspan: 1,
					}
				}
			} else {
				mList[rowVal] = {
					num: 1,
					index: index,
					newIndex: index + 1,
				}
				v[m + "-span"] = {
					rowspan: 1,
					colspan: 1,
				}
			}
			return v
		})
	})
	return data
}

// 计算每个单机所占的行数
function _getStandaloneSpanRows(tableData) {
	tableData.map((td, index) => {
		if (index > 0) {
			let previous = tableData[index - 1]
			// 主机合并
			if (td.maxCnt > 1 && td.hpCnt < td.maxCnt && previous.hpSpanRows < 2) {
				td.hpSpanRows = td.maxCnt
			} else {
				td.hpSpanRows = (index > 0 && previous.hpSpanRows > 1) ? 0 : 1
			}
			// 新风机合并
			if (td.maxCnt > 1 && td.dhCnt < td.maxCnt && previous.dhSpanRows < 2) {
				td.dhSpanRows = td.maxCnt
			} else {
				td.dhSpanRows = (index > 0 && previous.dhSpanRows > 1) ? 0 : 1
			}
			// 换热站合并
			if (td.maxCnt > 1 && td.hexCnt < td.maxCnt && previous.hexSpanRows < 2) {
				td.hexSpanRows = td.maxCnt
			} else {
				td.hexSpanRows = (index > 0 && previous.hexSpanRows > 1) ? 0 : 1
			}
			// 末端合并
			if (td.maxCnt > 1 && previous.cbSpanRows < 2) {
				td.cbSpanRows = td.maxCnt
			} else {
				td.cbSpanRows = (index > 0 && previous.cbSpanRows > 1) ? 0 : 1
			}
			tableData[index] = td
		} else {
			td.hpSpanRows = (td.maxCnt > 1 && td.hpCnt < td.maxCnt) ? td.maxCnt : 1
			td.dhSpanRows = (td.maxCnt > 1 && td.dhCnt < td.maxCnt) ? td.maxCnt : 1
			td.hexSpanRows = (td.maxCnt > 1 && td.hexCnt < td.maxCnt) ? td.maxCnt : 1
			td.cbSpanRows = td.maxCnt
			tableData[index] = td
		}
		return td
	})
	return tableData
}


